#
# spec file for package tlp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name   TLP
Name:           tlp
Version:        1.0
Release:        1.1
Summary:        Save battery power on laptops
License:        GPL-2.0+ and GPL-3.0+
Group:          Hardware/Mobile
Url:            http://linrunner.de/tlp
Source:         https://github.com/linrunner/%{_name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gzip
BuildRequires:  systemd-rpm-macros
Requires:       hdparm
Requires:       iw
Requires:       pciutils
Requires:       rfkill
Requires:       usbutils
Requires:       util-linux >= 2.17
Recommends:     %{name}-rdw = %{version}
Recommends:     ethtool
Recommends:     lsb-release
Recommends:     smartmontools
Suggests:       acpi-call-kmp
Suggests:       tp-smapi-kmp
Conflicts:      laptop-mode-tools
BuildArch:      noarch
%{?systemd_requires}

%description
TLP implements advanced power management for Linux.
TLP is a pure command line tool with automated background tasks.
It does not contain a GUI.

%package rdw
Summary:        TLP Radio Device Wizard
Group:          Hardware/Mobile
Requires:       NetworkManager
Requires:       tlp = %{version}

%description rdw
TLP implements advanced power management for Linux.
TLP is a pure command line tool with automated background tasks.
It does not contain a GUI.

Switch radios upon network connect/disconnect and dock/undock.

%prep
%setup -q -n %{_name}-%{version}

%build
make %{?_smp_mflags} V=1 \
  TLP_ULIB=%{_libexecdir}/udev \
  TLP_SYSD=%{_unitdir}

%install
%make_install \
  TLP_WITH_SYSTEMD=1           \
  TLP_NO_INIT=1                \
  TLP_ULIB=%{_libexecdir}/udev \
  TLP_SYSD=%{_unitdir}
make install-man \
  DESTDIR=%{buildroot}

for rc in rc%{name} rc%{name}-sleep; do
    ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/$rc
done

%pre
%service_add_pre %{name}.service %{name}-sleep.service

%post
%service_add_post %{name}.service %{name}-sleep.service

%postun
%service_del_postun %{name}.service %{name}-sleep.service

%preun
%service_del_preun %{name}.service %{name}-sleep.service

%files
%defattr(-,root,root)
%doc AUTHORS COPYING LICENSE README
%config(noreplace) %{_sysconfdir}/default/%{name}
%{_bindir}/bluetooth
%{_bindir}/run-on-*
%{_bindir}/%{name}-*
%{_bindir}/wifi
%{_bindir}/wwan
%{_sbindir}/*%{name}*
%{_unitdir}/%{name}*.service
%{_datadir}/%{name}/
%{_libexecdir}/pm-utils/
%dir %{_libexecdir}/udev/
%dir %{_libexecdir}/udev/rules.d/
%{_libexecdir}/udev/%{name}-usb-udev
%{_libexecdir}/udev/rules.d/85-%{name}.rules
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/bluetooth
%{_datadir}/bash-completion/completions/%{name}*
%{_datadir}/bash-completion/completions/wifi
%{_datadir}/bash-completion/completions/wwan
%{_mandir}/man?/*.?%{?ext_man}

%files rdw
%defattr(-,root,root)
%{_sysconfdir}/NetworkManager/
%dir %{_libexecdir}/udev/
%dir %{_libexecdir}/udev/rules.d/
%{_libexecdir}/udev/rules.d/85-%{name}-rdw.rules
%{_libexecdir}/udev/%{name}-rdw-udev

%changelog
* Fri May 26 2017 sor.alexei@meowr.ru
- Update to version 1.0:
  * General:
  - TLP_PERSISTENT_DEFAULT: Use TLP_DEFAULT_MODE regardless of
    the actual power source.
  * Device Bays:
  - BAY_POWEROFF_ON_AC: Power off optical drive not only on bat
    (gh#linrunner/TLP#243)
  * Graphics:
  - RUNTIME_PM_DRIVER_BLACKLIST: When unconfigured default to
    "amdgpu nouveau nvidia radeon"; driver default control=auto
    allows PRIME/Bumblebee to turn the dGPU off and prevents
    accidential power-on during boot as well.
  - Exclude Nvidia dGPU from runtime power management even when
    no driver is associated (improve compatibility with
    Bumblebee).
  * PCI(e) devices
  - RUNTIME_PM_ALL removed (default to RUNTIME_PM_ALL=1
    internally).
  * Processor:
  - CPU_HWP_ON_AC/BAT: HWP energy performance hints; needs
    Linux 4.10 and Intel Skylake CPU or newer, intel_pstate only.
  * ThinkPad Battery:
  - RESTORE_THRESHOLDS_ON_BAT: Restore charge thresholds on
    battery.
  - Detect ThinkPad *70 models.
  - Detect ThinkPad 13 (1st and 2nd Gen) as unsupported
    (gh#linrunner/TLP#227).
  - Change texts "ThinkPad (extended) battery functions" to
    "ThinkPad battery features".
  - tlp-stat:
    + Show "Charge total %%" when more than one battery is
    present.
    + Show battery temperature (tp-smapi only).
    + Show "unsupported" instead of "not installed" for tp-smapi
    incapable hardware.
  * USB:
  - USB_BLACKLIST_BTUSB: exclude bluetooth devices from
    autosuspend (gh#linrunner/TLP#239).
  - USB_BLACKLIST_PHONE: exclude phone devices from
    autosuspend (gh#linrunner/TLP#188).
  * tlp-stat:
  - -g|--graphics: Show graphics card data only.
  - i915: Explain enable_psr modes.
  - --psup: show power supply diagnostic.
  - SMART attribute G-Sense_Error_Rate.
  - -v: additional battery voltages.
  - Workqueue power efficient status.
  - Show Intel graphics parameters for Ubuntu's i915_bpo module.
  * Bugfixes:
  - init start: Apply powersave regardless of previous state
    (gh#linrunner/TLP#237).
  - tlp-stat: Intercept non-existing or invalid charge values
    (gh#linrunner/TLP#256).
* Thu Aug 18 2016 sor.alexei@meowr.ru
- Update to version 0.9:
  * General:
  - Block concurrent invocation of TLP.
  * Disc drives:
  - AHCI runtime power management for host controllers and
    attached disc drives.
  - SATA_LINKPWR_BLACKLIST: Exclude SATA host devices from power
    management.
  * Radio Devices:
  - Finally remove deprecated DEVICES_TO_ENABLE_ON_RADIOSW code
    (works with Ubuntu 12.04/Linux 3.2 only).
  - Change WIFI_PWR_ON_AC/BAT default config values to off/on for
    better usability (1/5 is still supported for backwards
    compatibility).
  * Radio Device Wizard (tlp-rdw):
  - Add another ThinkPad OneLink Pro Dock USB LAN (17ef:304).
  * (ThinkPad) Battery:
  - tlp-stat:
    + Distinguish incompatible hardware from load errors
    (gh#linrunner/TLP#160).
    + Display battery charge and capacity values in %%.
    + More selective suggestions for tp-smapi/acpi-call kernel
    modules.
  * tlp-stat:
  - Intel graphics: include i915 parameters enable_dc, enable_psr,
    modeset.
  - --pev: monitor power supply udev events
    (gh#linrunner/TLP#172).
  - Processor:
    + Display available scaling governors.
    + intel_pstate: display turbo_pct, num_pstates.
  - Storage Devices:
  - Recognise blk-mq I/O scheduler.
  - SMART attributes Power_Cycle_Count, Unused_Rsvd_Blk_Cnt_Tot,
    NAND_Writes_1GiB.
  - Suggestions: Add *60 models for tp-smapi/acpi-call.
  - System Info: Display boot mode UEFI / BIOS.
  - TLP Status:
    + Display time and mode of tlp's last invocation.
    + Issue warning when systemd-rfkill[@].service is not masked.
  - Wireless: Display type in interface list.
  * Bugfixes
  - Handle kernel with built-in acpi_call module properly
    (gh#linrunner/TLP#163).
  - Battery discharge does not terminate on ThinkPad E-series
    (gh#linrunner/TLP#170).
  - TLP does not notice power source change (gh#linrunner/TLP#172).
  - Do not touch wifi on shutdown when unconfigured
    (gh#linrunner/TLP#175).
  - Optimise rdw locking heuristics (gh#linrunner/TLP#176).
  - tlp-stat: Fix ata error count (filter "DevExch" caused by
    bay inserts).
  - tp-smapi: Do not load on unsupported ThinkPads.
  - Fix bash completion.
- Remove tlp-0.8-correct-udev-rules-path.patch: fixed upstream.
* Mon Jan  4 2016 sor.alexei@meowr.ru
- Add tlp-0.8-correct-udev-rules-path.patch: set correct udev
  rules path (boo#960498).
* Thu Aug  6 2015 sor.alexei@meowr.ru
- Update to 0.8:
  * General:
  - TLP_DEFAULT_MODE: change default operation mode to AC when
    no power supply can be detected (concerns some desktop and
    embedded hardware only).
  * Radio Devices:
  - Resume: restore bluetooth state.
  * Radio Device Wizard (tlp-rdw):
  - Support ThinkPad OneLink Dock Basic/Pro for dock/undock
    events.
  - Detect systemd "predictable network interface names" for
    WWAN.
  * ThinkPad Battery:
  - tpacpi-bat: new upstream version 2.2: get ASL path from
    /sys/class/power_supply/*/device/path; avoids unnecessary
    "AE_NOT_FOUND" kernel messages.
  - tlp-stat:
  - Show "No batteries detected."
  - Explain battery status "Unknown" as "threshold effective".
  - Show battery cell group voltages (verbose mode, tp-smapi
    only).
  - Show acpi-call suggestion for ThinkPad *40, *50, X1
    models.
  * USB:
  - Remove USB_DRIVER_BLACKLIST.
  * tlp-stat:
  - Show warnings for ata errors by default.
  * Bugfixes:
  - tlp-stat: detect kernel config with PM_RUNTIME=N.
  - tlp recalibrate: fix exitcode check.
  - USB autosuspend: write power/control if actually changing
    only.
  - Ignore missing files in /proc/sys/fs/xfs.
  - Fix udev event processing for AC/BAT sw.
* Sat Jan 31 2015 sor.alexei@meowr.ru
- Update to 0.7:
  * Processor:
  - Limit max/min P-state to control power dissipation of the
    CPU (intel_pstate only)
  - Set performance versus energy savings policy
    (x86_energy_perf_policy)
  * USB:
  - USB_DRIVER_BLACKLIST: exclude devices assigned to the listed
    drivers from USB autosuspend; default: usbhid
  - USB_BLACKLIST_WWAN: match internal driver list instead of USB
    vendor ids
  - USB_WHITELIST: include devices into USB autosuspend even if
    already excluded by the driver or WWAN blacklists
  * Radio devices:
  - DEVICES_TO_ENABLE_ON_AC/DISABLE_ON_BAT /
    DISABLE_ON_BAT_NOT_IN_USE: enable/disable radio devices upon
    change of power source (excluding connected devices)
  * ThinkPad Battery:
  - Issue #105: provide proper return codes for all battery
    functions
  - Issue #106: setcharge allowed on battery power
  - Do not activate new thresholds with force_discharge anymore
    (tp-smapi)
  - tpacpi-bat: support for ThinkPad E325 charge thresholds
  * Misc:
  - RUNTIME_PM_DRIVER_BLACKLIST: exclude PCI(e) devices assigned
    to drivers;
    default: radeon, nouveau (solves issue #94)
  - Support Dell Latitude docks
  - Support for NM 0.9.10
  - Issue #109: tlp-stat: report "unknown" power source when no
    AC detected
  - Issue #98: do not change autosuspend_delay_ms, keep kernel
    default settings
  - Exclude pseudo usb disks
  * tlp-stat:
  - New options -d|--disk, -e|--pcie, -p|--processor,
  - s|--system, -u|--usb
  - Show driver and connection state for all enabled radio
    devices
  - Show driver name in Runtime PM PCI(e) device list
  - Show type and state of docks and device bays
  - Show type of init system
  - Check if TLP's systemd services are enabled
  * udev:
  - Run change of power source in a detached subshell to avoid
    blocking udev
  - Fix dock/undock event processing for ThinkPad Adv Mini Dock
    and Ultrabase
  - Make USB device event processing more robust
    + Run in a detached subshell to avoid blocking udev
    + Wait 2s for subdevices to populate for proper
    black/whitelist detection
* Thu Nov 20 2014 sor.alexei@meowr.ru
- Adjust dependencies according to
  http://linrunner.de/en/tlp/docs/tlp-developer-documentation.html
* Wed Oct  8 2014 sor.alexei@meowr.ru
- Initial build.
